/*
 * Copyright (C) 2012 Michael Olbrich <m.olbrich@pengutonix.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */

#include "load.h"

#include <QtCore/QTime>
#include <QtCore/QThread>
#include <QtCore/QDebug>

class LoadThread : public QThread
{
public:
	LoadThread(QObject *parent = 0) :
		QThread(parent),
		level(100),
		running(false)
	{}

	int level;
	bool running;

protected:
	virtual void run()
	{
		volatile int i = 0;
		while (running) {
			QTime t = QTime::currentTime();
			for (int j = 0; j < 10000; ++j)
				++i;
		}
	}
};

Load::Load(QObject *parent) :
	QObject(parent),
	m_thread(new LoadThread(this))
{
}

Load::~Load()
{
}

bool Load::enabled() const
{
	return m_thread->isRunning();
}

void Load::setEnabled(bool enabled)
{
	if (m_thread->running == enabled)
		return;

	m_thread->running = enabled;
	if (enabled)
		m_thread->start();
	emit enabledChanged(enabled);
}

int Load::level() const
{
	return m_thread->level;
}

void Load::setLevel(int level)
{
	if (level == m_thread->level)
		return;
	if (level < 0)
		level = 0;
	if (level > 100)
		level = 100;
	m_thread->level = level;
	emit levelChanged(level);
}

